@@ -30,27 +30,11 @@ lm.mi <- function ( formula,  mi.object, ... )
     return( mi.lm.object );
 }
 
-print.mi.lm<-function( object ){
-  cat( "----------------------------------------\n" );
-  cat( "Pooled Estimate\n" );
-  cat( "----------------------------------------\n" );
-  print( object$call );
-  tab<-cbind( object$lm.mi.pooled[[1]], object$lm.mi.pooled[[2]] );
-  dimnames( tab )[[2]] <- c( "coef.est", "coef.se" );
-  print( tab );
-  cat( "---\n" );
-  cat( "----------------------------------------\n" );
-  cat( "Separate Estimate for each Imputation\n" );
-  cat( "----------------------------------------\n" );
-  for( i in 1:length( object$lm.mi.fit ) ) {
-    display( object$lm.mi.fit[[i]] );
-    cat( "----------------------------------------\n" );
-  }
-}
 
-display.mi.lm<-function( object ){
-  print.mi.lm( object );
-}
+
+
+
+
 #glm.mi.norm <- function (formula,mi.object,  family = gaussian, ...) 
 #{
 #    call <- match.call()
